# distributions

This package was made in the fulfillment of the requirements of the Udacity program: AWS Machine Learning Foundations. It is exposed in section: Introduction to Object-Oriented Programing (part 28)

The package covers the usage of a Gaussian and a Binomial Class, through a general distribution common to both classes. These classes are used to define Probabilities.

The code here is my implementation according to my developer experience. 

Enjoy it.

## Files

### distribution

#### General Distribution
#### Binomial Distribution
#### Gaussian Distribution
#### __init__

### test

## Installation
It is simple such as:

``pip install jam65st_distributions``

